cumulusci.robotframework.pageobjects package
============================================

Submodules
----------

cumulusci.robotframework.pageobjects.PageObjects module
-------------------------------------------------------

.. automodule:: cumulusci.robotframework.pageobjects.PageObjects
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.pageobjects.baseobjects module
-------------------------------------------------------

.. automodule:: cumulusci.robotframework.pageobjects.baseobjects
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.robotframework.pageobjects
    :members:
    :undoc-members:
    :show-inheritance:
